Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
arrakis_server/__init__.py | (no class) | 5 | 3 | 0 | 40.0%
arrakis_server/__main__.py | (no class) | 71 | 71 | 0 | 0.0%
arrakis_server/arrow.py | (no class) | 43 | 18 | 0 | 58.1%
arrakis_server/backends/__init__.py | (no class) | 16 | 3 | 0 | 81.2%
arrakis_server/backends/mock/__init__.py | MockBackend | 49 | 34 | 0 | 30.6%
arrakis_server/backends/mock/__init__.py | (no class) | 45 | 2 | 0 | 95.6%
arrakis_server/backends/mock/channels/__init__.py | (no class) | 0 | 0 | 0 | 100.0%
arrakis_server/channel.py | Channel | 5 | 1 | 0 | 80.0%
arrakis_server/channel.py | (no class) | 16 | 1 | 0 | 93.8%
arrakis_server/constants.py | (no class) | 2 | 0 | 0 | 100.0%
arrakis_server/errors.py | TimeRangeUnavailableError | 2 | 2 | 0 | 0.0%
arrakis_server/errors.py | ChannelUnavailableError | 2 | 2 | 0 | 0.0%
arrakis_server/errors.py | RequestUnavailableError | 0 | 0 | 0 | 100.0%
arrakis_server/errors.py | RequestCancelledError | 0 | 0 | 0 | 100.0%
arrakis_server/errors.py | RequestTimedOutError | 0 | 0 | 0 | 100.0%
arrakis_server/errors.py | (no class) | 12 | 0 | 0 | 100.0%
arrakis_server/metadata.py | ChannelMetadataBackend | 0 | 0 | 4 | 100.0%
arrakis_server/metadata.py | ChannelConfigBackend | 68 | 16 | 0 | 76.5%
arrakis_server/metadata.py | (no class) | 26 | 0 | 5 | 100.0%
arrakis_server/partition.py | (no class) | 64 | 0 | 0 | 100.0%
arrakis_server/schemas.py | (no class) | 21 | 3 | 0 | 85.7%
arrakis_server/scope.py | ScopeMap | 57 | 25 | 0 | 56.1%
arrakis_server/scope.py | ScopeInfo | 6 | 2 | 0 | 66.7%
arrakis_server/scope.py | Retention | 12 | 4 | 0 | 66.7%
arrakis_server/scope.py | (no class) | 54 | 1 | 0 | 98.1%
arrakis_server/server.py | ArrakisFlightServer | 159 | 71 | 0 | 55.3%
arrakis_server/server.py | (no class) | 65 | 0 | 0 | 100.0%
arrakis_server/traits.py | ServerBackend | 5 | 3 | 5 | 40.0%
arrakis_server/traits.py | PublishServerBackend | 0 | 0 | 2 | 100.0%
arrakis_server/traits.py | (no class) | 33 | 1 | 9 | 97.0%
Total |  | 838 | 263 | 25 | 68.6%

No items found using the specified filter.